library(tidyverse)
library(mc2d)
library(fitdistrplus)
library(car)
library(Hmisc) # to produce LaTeX output
set.seed(1885)
ndvar(5000) # Variability dimension
ndunc(2000) # Uncertainty dimension

dpipwe <- read.csv("final bloom study data.csv", as.is=TRUE)
dpipwe <- dpipwe %>% 
  dplyr::select(sex=Sex,
                hp.w=Hepato.gm,
                size=Carapace.cm,
                pst=Total.PST.convert, 
                pst.ind=Total.PST.convert.indicator) %>%
  dplyr::mutate(pst=pst*1000)

print.data.frame(head(dpipwe))

sardi <- read.csv("final SARDI lobster data.csv", as.is=TRUE)
sardi <- sardi %>%
  dplyr::select(sex=Sex, hp.w=HP.wt, size=Carpace,
                pst=Total.PST.convert,
                pst.ind=Total.PST.convert.indicator)

print.data.frame(head(sardi))

bloom.all <- rbind(dpipwe, sardi)
bloom <- bloom.all %>% filter (sex=="M")
bloom.legal <- bloom %>% filter (size > 11) # Only males

## Only use data from legal size rock lobsters
pst.data <- with(bloom.legal, data.frame(left=pst, right=pst))
pst.data$left[bloom.legal$pst.ind==0] <- NA
pst.fit.ln <- fitdistcens(log10(pst.data), "norm")

cdfcompcens(list(pst.fit.ln), legendtext = c("log10-normal"))

summary(pst.fit.ln)

ggplot(bloom.legal, aes(x=hp.w))+
  geom_density()+
  labs(x="Hepatopancreas Weight (g)", y="")+
  theme_bw()

with(bloom, descdist(hp.w[!is.na(hp.w)], boot = 1000))

hpw <- with(bloom, hp.w[!is.na(hp.w)])
hpw.fit.gam <- fitdist(hpw, "gamma")
hpw.fit.ln <- fitdist(hpw, "lnorm")
cdfcomp(list(hpw.fit.gam, hpw.fit.ln), legendtext = c("gamma","lnorm"))

gofstat(list(hpw.fit.gam, hpw.fit.ln), fitnames = c("gamma","lnorm"))

ggplot(bloom, aes(x=size, y=hp.w^(1/3)))+
  geom_point()+
  geom_smooth(method="lm")+
  labs(x="Carapace length (cm)", "Weight (g)")+
  theme_bw()

hpw.fit <- lm(hp.w^(1/3) ~ size, data=bloom.legal)
hpw.fit
#plot(hpw.fit) # Check diagnostics - all OK
predict(hpw.fit, newdata=data.frame(size=c(11,23)),
        level=0.99, interval="prediction")^3

ggplot(bloom, aes(x=log10(hp.w), y=log10(pst)))+
  geom_point() +
  labs(x="log10 Weight", y="log10 PST concentration")+
  theme_bw()

mc.pst <- 10^(mcstoc(rnorm, type="VU",
                     mean=pst.fit.ln$est[1],
                     sd=pst.fit.ln$est[2]))
## Truncate at the MRL to assess effect of reg limit.
mc.pst.mrl <- 10^(mcstoc(rnorm, type="VU",
                         rtrunc=TRUE,  lsup=log10(800),
                         mean=pst.fit.ln$est[1],
                         sd=pst.fit.ln$est[2]))
mc.hpw <- exp(mcstoc(rnorm, type="VU",
                     rtrunc=TRUE, linf=log(90), lsup=log(400),
                     mean=hpw.fit.ln$est[1],
                     sd=hpw.fit.ln$est[2]))

cook <- read.csv("Cooking Study Data.csv", as.is=TRUE)
names(cook)[4] <- "pst"
cook <- cook %>%
  dplyr::select(treat=Treat, hp.w=HP.Wt, pst)
cook$treat <- factor(cook$treat, levels=c("Raw","Boiled","Steamed"))

ggplot(cook, aes(x=treat, y=log10(hp.w)))+
  geom_boxplot() +
  labs(x="",y="Hepatopancreas Weight (log10 g)") +
  theme_bw()

leveneTest(log10(hp.w)~treat, data=cook)
leveneTest(log10(pst)~treat, data=cook)

fm.hpw <- lm(log10(hp.w)~treat, data=cook)
Anova(fm.hpw, white.adjust=TRUE)

coef(fm.hpw)

sqrt(diag(vcov(fm.hpw)))
sqrt(diag(hccm(fm.hpw)))

ggplot(cook, aes(x=treat, y=log10(pst)))+
  geom_boxplot() +
  labs(x="",y="log10 PST concentration") +
  theme_bw()

Anova(lm(pst~treat, data=cook))

mc.boil.perc <- 10^mcstoc(rnorm, type="VU",
                          mean=coef(fm.hpw)[2],
                          sd=sqrt(diag(hccm(fm.hpw)))[2])
## Truncated normal where b = upper limit
mc.steam.perc <- 10^mcstoc(rnorm, type="VU",
                           rtrunc=TRUE, lsup=0,
                           mean=coef(fm.hpw)[3],
                           sd=sqrt(diag(hccm(fm.hpw)))[3])

livers <- read.csv("Livers consumed.csv", as.is=TRUE)
livers <- livers %>% rename(id=Responses, cons=Livers)

head(livers)

with(livers, descdist(cons, boot = 1000))

eat.fit.gam <- fitdist(livers$cons, "gamma")
eat.fit.ln <- fitdist(livers$cons, "lnorm")
eat.fit.exp <- fitdist(livers$cons, "exp")
cdfcomp(list(eat.fit.gam, eat.fit.ln, eat.fit.exp), legendtext = c("gamma","lnorm","exp"))

gofstat(list(eat.fit.gam, eat.fit.ln, eat.fit.exp), fitnames = c("gamma","lnorm","exp"))

mc.eat.fr <- exp(mcstoc(rnorm, type="VU",
                        rtrunc=TRUE, lsup=log(4),
                        mean=eat.fit.ln$est[1],
                        sd=eat.fit.ln$est[2]))
mc.eat.fr <- cornode(mc.hpw, mc.eat.fr, target=-0.3)$mc.eat.fr

## Convert HP weight to kg.
mc.eat.raw <- (mc.hpw/1000)*mc.eat.fr
mc.eat.boil <- (mc.hpw/1000)*mc.eat.fr*mc.boil.perc
mc.eat.steam <- (mc.hpw/1000)*mc.eat.fr*mc.steam.perc
## Adjust for a 60kg person
mc.exp.raw <- mc.pst*mc.eat.raw/60
mc.exp.boil <- mc.pst*mc.eat.boil/60
mc.exp.steam <- mc.pst*mc.eat.steam/60
## Repeat for scenario of limiting to MRL of 800
mc.exp.mrl.raw <- mc.pst.mrl*mc.eat.raw/60
mc.exp.mrl.boil <- mc.pst.mrl*mc.eat.boil/60
mc.exp.mrl.steam <- mc.pst.mrl*mc.eat.steam/60
## Create MC objects for simulation evaluation
mc.EA.raw <- mc(mc.pst, mc.hpw, mc.eat.fr, mc.eat.raw, mc.exp.raw, mc.exp.mrl.raw)
mc.EA.boil <- mc(mc.pst, mc.hpw, mc.eat.fr, mc.boil.perc, mc.eat.boil,
                 mc.exp.boil, mc.exp.mrl.boil)
mc.EA.steam <- mc(mc.pst, mc.hpw, mc.eat.fr, mc.steam.perc, mc.eat.steam,
                  mc.exp.steam, mc.exp.mrl.steam)

pr <- c(0.5, 0.95, 0.975, 0.99, 0.999, 1)
s.raw <- summary(mc.EA.raw, prob=pr)
s.boil <- summary(mc.EA.boil, prob=pr)
s.steam <- summary(mc.EA.steam, prob=pr)

x <- rbind(s.raw$mc.exp.raw[-2,], # Uncert. summary of mean
           s.boil$mc.exp.boil[-2,], # Uncert. summary of mean
           s.steam$mc.exp.steam[-2,]) # Uncert. summary of mean
latex(format.df(x, cdec=c(rep(3, ncol(x)-2), 0,0), big.mark=","), 
      file="", title="", label="tbl:output", col.just=rep("r",ncol(x)),
      n.rgroup=c(3,3,3), rgroup=c("Raw","Boiled","Steamed"),
      caption="Summary output (PST $\\mu{}g$ per kg body weight) of the exposure assessment.")

x <- rbind(s.raw$mc.exp.mrl.raw[-2,], # Uncert. summary of mean
           s.boil$mc.exp.mrl.boil[-2,], # Uncert. summary of mean
           s.steam$mc.exp.mrl.steam[-2,]) # Uncert. summary of mean
latex(format.df(x, cdec=c(rep(3, ncol(x)-2), 0,0), big.mark=","), 
      file="", title="", label="tbl:output.mrl", col.just=rep("r",ncol(x)),
      n.rgroup=c(3,3,3), rgroup=c("Raw","Boiled","Steamed"),
      caption="Summary output (PST $\\mu{}g$ per kg body weight) of the exposure assessment under a regulatory limit of 800 $\\mu{}g/kg$.")

summary(mc.eat.raw, prob=pr)
summary(mc.eat.boil, prob=pr)
summary(mc.eat.steam, prob=pr)

summary(mc.exp.raw>2, prob=NULL)
summary(mc.exp.boil>2, prob=NULL)
summary(mc.exp.steam>2, prob=NULL)

summary(mc.exp.raw*60/85.9>2, prob=NULL) #male
summary(mc.exp.raw*60/71.1>2, prob=NULL) #female
summary(mc.exp.boil*60/85.9>2, prob=NULL)
summary(mc.exp.boil*60/71.1>2, prob=NULL)
summary(mc.exp.steam*60/85.9>2, prob=NULL)
summary(mc.exp.steam*60/71.1>2, prob=NULL)

summary(mc.exp.mrl.raw>2, prob=NULL)
summary(mc.exp.mrl.boil>2, prob=NULL)
summary(mc.exp.mrl.steam>2, prob=NULL)

summary(mc.exp.mrl.raw*60/85.9>2, prob=NULL) #male
summary(mc.exp.mrl.raw*60/71.1>2, prob=NULL) #female
summary(mc.exp.mrl.boil*60/85.9>2, prob=NULL)
summary(mc.exp.mrl.boil*60/71.1>2, prob=NULL)
summary(mc.exp.mrl.steam*60/85.9>2, prob=NULL)
summary(mc.exp.mrl.steam*60/71.1>2, prob=NULL)

sessionInfo()

s.raw

s.boil

s.steam

print(mcratio(mc.EA.raw), digits=3)
print(mcratio(mc.EA.boil), digits=3)
print(mcratio(mc.EA.steam), digits=3)

tor.raw <- tornado(mc.EA.raw)
tor.boil <- tornado(mc.EA.boil)
tor.steam <- tornado(mc.EA.steam)

tor.raw; tor.boil; tor.steam

mc.eat.fr <- cornode(mc.hpw, mc.eat.fr, target=0.0)$mc.eat.fr
mc.eat.raw <- (mc.hpw/1000)*mc.eat.fr
mc.eat.boil <- (mc.hpw/1000)*mc.eat.fr*mc.boil.perc
mc.eat.steam <- (mc.hpw/1000)*mc.eat.fr*mc.steam.perc
## Adjust for a 60kg person
mc.exp.raw <- mc.pst*mc.eat.raw/60
mc.exp.boil <- mc.pst*mc.eat.boil/60
mc.exp.steam <- mc.pst*mc.eat.steam/60
## Create MC objects for simulation evaluation
mc.EA.raw <- mc(mc.pst, mc.hpw, mc.eat.fr, mc.eat.raw, mc.exp.raw)
mc.EA.boil <- mc(mc.pst, mc.hpw, mc.eat.fr, mc.boil.perc, mc.eat.boil, mc.exp.boil)
mc.EA.steam <- mc(mc.pst, mc.hpw, mc.eat.fr, mc.steam.perc, mc.eat.steam,
                  mc.exp.steam)
pr <- c(0.5, 0.95, 0.975, 0.99, 0.999,1)

summary(mc.EA.raw, prob=pr)

summary(mc.EA.boil, prob=pr)

summary(mc.EA.steam, prob=pr)

summary(mc.exp.raw>2, prob=NULL)
summary(mc.exp.boil>2, prob=NULL)
summary(mc.exp.steam>2, prob=NULL)

win.metafile("plots/cdf_raw.wmf")
plot(mc.exp.raw, 
     ylab="Cumulative probability",
     xlab=expression(paste("PST exposure (",mu,"g/kg)")))
dev.off()

mc.eat.fr <- cornode(mc.hpw, mc.eat.fr, target=-0.8)$mc.eat.fr
mc.eat.raw <- (mc.hpw/1000)*mc.eat.fr
mc.eat.boil <- (mc.hpw/1000)*mc.eat.fr*mc.boil.perc
mc.eat.steam <- (mc.hpw/1000)*mc.eat.fr*mc.steam.perc
## Adjust for a 60kg person
mc.exp.raw <- mc.pst*mc.eat.raw/60
mc.exp.boil <- mc.pst*mc.eat.boil/60
mc.exp.steam <- mc.pst*mc.eat.steam/60
## Create MC objects for simulation evaluation
mc.EA.raw <- mc(mc.pst, mc.hpw, mc.eat.fr, mc.eat.raw, mc.exp.raw)
mc.EA.boil <- mc(mc.pst, mc.hpw, mc.eat.fr, mc.boil.perc, mc.eat.boil, mc.exp.boil)
mc.EA.steam <- mc(mc.pst, mc.hpw, mc.eat.fr, mc.steam.perc, mc.eat.steam,
                  mc.exp.steam)
pr <- c(0.5, 0.95, 0.975, 0.99, 0.999, 1)

summary(mc.EA.raw, prob=pr)

summary(mc.EA.boil, prob=pr)

summary(mc.EA.steam, prob=pr)

summary(mc.exp.raw>2, prob=NULL)
summary(mc.exp.boil>2, prob=NULL)
summary(mc.exp.steam>2, prob=NULL)

nrow(bloom.all)
sum(bloom.all$pst.ind)
summary(bloom.all$pst[bloom.all$pst.ind==1])
sd(bloom.all$pst[bloom.all$pst.ind==1])
sum(bloom.all$pst[bloom.all$pst.ind==1] > 800)

nrow(bloom.legal)
sum(bloom.legal$pst.ind)
summary(bloom.legal$pst[bloom.legal$pst.ind==1])
sd(bloom.legal$pst[bloom.legal$pst.ind==1])
sum(bloom.legal$pst[bloom.legal$pst.ind==1] > 800)

nrow(bloom)
sum(bloom$pst.ind)
summary(bloom$pst[bloom$pst.ind==1])
sd(bloom$pst[bloom$pst.ind==1])
sum(bloom$pst[bloom$pst.ind==1] > 800)

bloom.f <- bloom.all %>% filter(sex=="F")
nrow(bloom.f)
sum(bloom.f$pst.ind)
summary(bloom.f$pst[bloom.f$pst.ind==1])
sd(bloom.f$pst[bloom.f$pst.ind==1])
sum(bloom.f$pst[bloom.f$pst.ind==1] > 800)

bloom.fm <- bloom.all %>% filter(sex=="")
nrow(bloom.fm)
sum(bloom.fm$pst.ind)
summary(bloom.fm$pst[bloom.fm$pst.ind==1])
sd(bloom.fm$pst[bloom.fm$pst.ind==1])
sum(bloom.fm$pst[bloom.fm$pst.ind==1] > 800)

Anova(lm(log10(pst) ~ factor(sex), data=bloom.all, subset=sex!=""))
summary(lm(log10(pst) ~ factor(sex), data=bloom.all, subset=sex!=""))

Anova(lm(log10(pst) ~ factor(sex), data=bloom.all))
summary(lm(log10(pst) ~ factor(sex), data=bloom.all))

## Significance of the relationship between size and PST
## with(bloom, plot(log10(size), log10(pst)))
Anova(lm(log10(pst) ~ log10(size), data=bloom.all))
Anova(lm(log10(pst) ~ log10(size), data=bloom.legal))
Anova(lm(log10(pst) ~ log10(hp.w), data=bloom.all))
Anova(lm(log10(pst) ~ sex, data=bloom.all))
